// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
var _a;
import * as Errors from "./error.mjs";
import * as Uploads from "./uploads.mjs";
import * as Core from "./core.mjs";
import * as API from "./resources/index.mjs";
/**
 * API Client for interfacing with the Dhan SDK API.
 */
export class DhanSDK extends Core.APIClient {
    /**
     * API Client for interfacing with the Dhan SDK API.
     *
     * @param {string} [opts.baseURL=process.env['DHAN_SDK_BASE_URL'] ?? https://api.dhan.co/v2] - Override the default base URL for the API.
     * @param {number} [opts.timeout=1 minute] - The maximum amount of time (in milliseconds) the client will wait for a response before timing out.
     * @param {number} [opts.httpAgent] - An HTTP agent used to manage HTTP(s) connections.
     * @param {Core.Fetch} [opts.fetch] - Specify a custom `fetch` function implementation.
     * @param {number} [opts.maxRetries=2] - The maximum number of times the client will retry a request.
     * @param {Core.Headers} opts.defaultHeaders - Default headers to include with every request to the API.
     * @param {Core.DefaultQuery} opts.defaultQuery - Default query parameters to include with every request to the API.
     */
    constructor({ baseURL = Core.readEnv('DHAN_SDK_BASE_URL'), ...opts } = {}) {
        const options = {
            ...opts,
            baseURL: baseURL || `https://api.dhan.co/v2`,
        };
        super({
            baseURL: options.baseURL,
            timeout: options.timeout ?? 60000 /* 1 minute */,
            httpAgent: options.httpAgent,
            maxRetries: options.maxRetries,
            fetch: options.fetch,
        });
        this.orders = new API.Orders(this);
        this.trades = new API.Trades(this);
        this.foreverOrders = new API.ForeverOrders(this);
        this.positions = new API.Positions(this);
        this.holdings = new API.Holdings(this);
        this.edis = new API.Edis(this);
        this.killswitch = new API.KillswitchResource(this);
        this.margincalculator = new API.Margincalculator(this);
        this.funds = new API.Funds(this);
        this.statements = new API.Statements(this);
        this.charts = new API.Charts(this);
        this._options = options;
    }
    defaultQuery() {
        return this._options.defaultQuery;
    }
    defaultHeaders(opts) {
        return {
            ...super.defaultHeaders(opts),
            ...this._options.defaultHeaders,
        };
    }
}
_a = DhanSDK;
DhanSDK.DhanSDK = _a;
DhanSDK.DEFAULT_TIMEOUT = 60000; // 1 minute
DhanSDK.DhanSDKError = Errors.DhanSDKError;
DhanSDK.APIError = Errors.APIError;
DhanSDK.APIConnectionError = Errors.APIConnectionError;
DhanSDK.APIConnectionTimeoutError = Errors.APIConnectionTimeoutError;
DhanSDK.APIUserAbortError = Errors.APIUserAbortError;
DhanSDK.NotFoundError = Errors.NotFoundError;
DhanSDK.ConflictError = Errors.ConflictError;
DhanSDK.RateLimitError = Errors.RateLimitError;
DhanSDK.BadRequestError = Errors.BadRequestError;
DhanSDK.AuthenticationError = Errors.AuthenticationError;
DhanSDK.InternalServerError = Errors.InternalServerError;
DhanSDK.PermissionDeniedError = Errors.PermissionDeniedError;
DhanSDK.UnprocessableEntityError = Errors.UnprocessableEntityError;
DhanSDK.toFile = Uploads.toFile;
DhanSDK.fileFromPath = Uploads.fileFromPath;
export const { DhanSDKError, APIError, APIConnectionError, APIConnectionTimeoutError, APIUserAbortError, NotFoundError, ConflictError, RateLimitError, BadRequestError, AuthenticationError, InternalServerError, PermissionDeniedError, UnprocessableEntityError, } = Errors;
export var toFile = Uploads.toFile;
export var fileFromPath = Uploads.fileFromPath;
(function (DhanSDK) {
    DhanSDK.Orders = API.Orders;
    DhanSDK.Trades = API.Trades;
    DhanSDK.ForeverOrders = API.ForeverOrders;
    DhanSDK.Positions = API.Positions;
    DhanSDK.Holdings = API.Holdings;
    DhanSDK.Edis = API.Edis;
    DhanSDK.KillswitchResource = API.KillswitchResource;
    DhanSDK.Margincalculator = API.Margincalculator;
    DhanSDK.Funds = API.Funds;
    DhanSDK.Statements = API.Statements;
    DhanSDK.Charts = API.Charts;
})(DhanSDK || (DhanSDK = {}));
export default DhanSDK;
//# sourceMappingURL=index.mjs.map