import { APIResource } from "../resource.js";
import * as Core from "../core.js";
import * as MargincalculatorAPI from "./margincalculator.js";
export declare class Margincalculator extends APIResource {
    /**
     * Margin Calculation API lets you calculate span, exposure, var, brokerage,
     * leverage, available margin values for any type of order and instrument.
     */
    calculate(params: MargincalculatorCalculateParams, options?: Core.RequestOptions): Core.APIPromise<KnowYourMargin>;
}
export interface KnowYourMargin {
    /**
     * Available balance to trade
     */
    availableBalance?: number;
    /**
     * Applicable brokerage
     */
    brokerage?: number;
    /**
     * Available exposure margin
     */
    exposureMargin?: number;
    /**
     * Insufficient balance
     */
    insufficientBalance?: number;
    /**
     * Applicable leverage
     */
    leverage?: string;
    /**
     * Available span margin
     */
    spanMargin?: number;
    /**
     * Total available margin to trade
     */
    totalMargin?: number;
    /**
     * Variable margin
     */
    variableMargin?: number;
}
export interface MargincalculatorCalculateParams {
    /**
     * | Body param:  | **Enums** | **Exchange**      | **Segment** |
     * | ------------ | --------- | ----------------- | ----------- |
     * | NSE_EQ       | NSE       | Equity Cash       |
     * | NSE_FNO      | NSE       | Futures & Options |
     * | NSE_CURRENCY | NSE       | Currency          |
     * | BSE_EQ       | BSE       | Equity Cash       |
     * | BSE_FNO      | BSE       | Futures & Options |
     * | BSE_CURRENCY | BSE       | Currency          |
     * | MCX_COMM     | MCX       | Commodity         |
     */
    exchangeSegment: 'NSE_EQ' | 'NSE_FNO' | 'NSE_CURRENCY' | 'BSE_EQ' | 'BSE_FNO' | 'BSE_CURRENCY' | 'MCX_COMM';
    /**
     * Body param: Signifies the type of transaction whether it's BUY or SELL
     */
    transactionType: 'BUY' | 'SELL';
    /**
     * Header param:
     */
    'access-token': string;
    /**
     * Body param: User specific identification generated by Dhan
     */
    dhanClientId?: string;
    /**
     * Body param: Price at which the order is requested to execute
     */
    price?: number;
    /**
     * | Body param: | **Enum Values**                                | **Description** |
     * | ----------- | ---------------------------------------------- | --------------- |
     * | CNC         | Cash & Carry for equity deliveries             |
     * | INTRADAY    | Intraday for Equity, Futures & Options         |
     * | MARGIN      | Carry Forward in Futures & Options             |
     * | CO          | Cover Order; entry and stop loss               |
     * | BO          | Bracket Order; entry, stop loss & target price |
     *
     * **CO & BO product types will be valid only for Intraday**
     */
    productType?: 'CNC' | 'INTRADAY' | 'MARGIN' | 'MTF' | 'CO' | 'BO';
    /**
     * Body param: Number of shares for the order
     */
    quantity?: number;
    /**
     * Body param: Exchange standard identification for each scrip
     */
    securityId?: string;
    /**
     * Body param: Price at which the order is requested to trigger
     */
    triggerPrice?: number;
}
export declare namespace Margincalculator {
    export import KnowYourMargin = MargincalculatorAPI.KnowYourMargin;
    export import MargincalculatorCalculateParams = MargincalculatorAPI.MargincalculatorCalculateParams;
}
//# sourceMappingURL=margincalculator.d.ts.map