// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as ExternalAPI from "./external.mjs";
export class Orders extends APIResource {
    constructor() {
        super(...arguments);
        this.external = new ExternalAPI.External(this._client);
    }
    /**
     * The order request API allows you to place new order.
     */
    create(params, options) {
        const { 'access-token': accessToken, ...body } = params;
        return this._client.post('/orders', {
            body,
            ...options,
            headers: { 'access-token': accessToken, ...options?.headers },
        });
    }
    /**
     * The api allows you to retrieve the details of an order placed during the day
     * with their last updated status, with their order id.
     */
    retrieve(orderId, params, options) {
        const { 'access-token': accessToken } = params;
        return this._client.get(`/orders/${orderId}`, {
            ...options,
            headers: { 'access-token': accessToken, ...options?.headers },
        });
    }
    /**
     * The api allows you modify pending order in orderbook. The fields that can be
     * modified are price, quantity, order type & validity.
     */
    update(orderId, params, options) {
        const { 'access-token': accessToken, ...body } = params;
        return this._client.put(`/orders/${orderId}`, {
            body,
            ...options,
            headers: { 'access-token': accessToken, ...options?.headers },
        });
    }
    /**
     * The API lets you retrieve an array of all orders requested in a day with their
     * last updated status.
     */
    list(params, options) {
        const { 'access-token': accessToken } = params;
        return this._client.get('/orders', {
            ...options,
            headers: { 'access-token': accessToken, ...options?.headers },
        });
    }
    /**
     * The api allows you to cancel a pending order using the order id
     */
    delete(orderId, params, options) {
        const { 'access-token': accessToken } = params;
        return this._client.delete(`/orders/${orderId}`, {
            ...options,
            headers: { 'access-token': accessToken, ...options?.headers },
        });
    }
    /**
     * The order request API allows you to place a new slice order.
     */
    slicing(params, options) {
        const { 'access-token': accessToken, ...body } = params;
        return this._client.post('/orders/slicing', {
            body,
            ...options,
            headers: { 'access-token': accessToken, ...options?.headers },
        });
    }
}
(function (Orders) {
    Orders.External = ExternalAPI.External;
})(Orders || (Orders = {}));
//# sourceMappingURL=orders.mjs.map