// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../resource';
import * as Core from '../core';
import * as FundsAPI from './funds';

export class Funds extends APIResource {
  /**
   * Get all information of your trading account like balance, margin utilised,
   * collateral, etc.
   */
  limit(params: FundLimitParams, options?: Core.RequestOptions): Core.APIPromise<FundLimit> {
    const { 'access-token': accessToken } = params;
    return this._client.get('/fundlimit', {
      ...options,
      headers: { 'access-token': accessToken, ...options?.headers },
    });
  }
}

export interface FundLimit {
  /**
   * Available balance to trade
   */
  availabelBalance?: number;

  /**
   * Amount blocked against payout request
   */
  blockedPayoutAmount?: number;

  /**
   * Amount received against collateral
   */
  collateralAmount?: number;

  /**
   * User specific identification generated by Dhan
   */
  dhanClientId?: string;

  /**
   * Amount available against selling deliveries
   */
  receiveableAmount?: number;

  /**
   * Start of the day amount
   */
  sodLimit?: number;

  /**
   * Amount utilised in the day
   */
  utilizedAmount?: number;

  /**
   * Amount available to withdraw to bank
   */
  withdrawableBalance?: number;
}

export interface FundLimitParams {
  'access-token': string;
}

export namespace Funds {
  export import FundLimit = FundsAPI.FundLimit;
  export import FundLimitParams = FundsAPI.FundLimitParams;
}
