// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../resource';
import * as Core from '../core';
import * as PositionsAPI from './positions';

export class Positions extends APIResource {
  /**
   * Users can retrieve a list of all open positions for the day. This includes all
   * F&O carryforward positions as well.
   */
  list(params: PositionListParams, options?: Core.RequestOptions): Core.APIPromise<PositionListResponse> {
    const { 'access-token': accessToken } = params;
    return this._client.get('/positions', {
      ...options,
      headers: { 'access-token': accessToken, ...options?.headers },
    });
  }

  /**
   * Users can convert their open position from intraday to delivery or delivery to
   * intraday.
   */
  convert(params: PositionConvertParams, options?: Core.RequestOptions): Core.APIPromise<void> {
    const { 'access-token': accessToken, ...body } = params;
    return this._client.post('/positions/convert', {
      body,
      ...options,
      headers: { Accept: '*/*', 'access-token': accessToken, ...options?.headers },
    });
  }
}

export interface Position {
  /**
   * Average buy price
   */
  buyAvg?: number;

  /**
   * Total quantity bought
   */
  buyQty?: number;

  /**
   * Carry forward F&O long quantities
   */
  carryForwardBuyQty?: number;

  /**
   * Carry forward F&O long value
   */
  carryForwardBuyValue?: number;

  /**
   * Carry forward F&O short quantities
   */
  carryForwardSellQty?: number;

  /**
   * Carry forward F&O short value
   */
  carryForwardSellValue?: number;

  /**
   * Cost price
   */
  costPrice?: number;

  crossCurrency?: boolean;

  /**
   * Quantities bought today
   */
  dayBuyQty?: number;

  /**
   * Value of quantities bought today
   */
  dayBuyValue?: number;

  /**
   * Quantities sold today
   */
  daySellQty?: number;

  /**
   * Value of quantities sold today
   */
  daySellValue?: number;

  /**
   * User specific identification generated by Dhan
   */
  dhanClientId?: string;

  /**
   * For F&O, expiry date of contract
   */
  drvExpiryDate?: string;

  /**
   * For Options, type CALL or PUT
   */
  drvOptionType?: 'CALL' | 'PUT' | 'NA';

  /**
   * For Options, Strike Price
   */
  drvStrikePrice?: number;

  /**
   * | **Enums**    | **Exchange** | **Segment**       |
   * | ------------ | ------------ | ----------------- |
   * | NSE_EQ       | NSE          | Equity Cash       |
   * | NSE_FNO      | NSE          | Futures & Options |
   * | NSE_CURRENCY | NSE          | Currency          |
   * | BSE_EQ       | BSE          | Equity Cash       |
   * | BSE_FNO      | BSE          | Futures & Options |
   * | BSE_CURRENCY | BSE          | Currency          |
   * | MCX_COMM     | MCX          | Commodity         |
   */
  exchangeSegment?:
    | 'NSE_EQ'
    | 'NSE_FNO'
    | 'NSE_CURRENCY'
    | 'BSE_EQ'
    | 'BSE_FNO'
    | 'BSE_CURRENCY'
    | 'MCX_COMM';

  /**
   * Multiplying factor for currency F&O
   */
  multiplier?: number;

  /**
   * buyQty minus sellQty equals netQty
   */
  netQty?: number;

  /**
   * | **Enum Values** | **Description**                                     |
   * | --------------- | --------------------------------------------------- |
   * | LONG            | When net bought quantity is more than sold quantity |
   * | SHORT           | When net sold quantity is more than bought quantity |
   * | CLOSED          | When no open position standing                      |
   */
  positionType?: 'LONG' | 'SHORT' | 'CLOSED';

  /**
   * | **Enum Values** | **Description**                                |
   * | --------------- | ---------------------------------------------- |
   * | CNC             | Cash & Carry for equity deliveries             |
   * | INTRADAY        | Intraday for Equity, Futures & Options         |
   * | MARGIN          | Carry Forward in Futures & Options             |
   * | CO              | Cover Order; entry and stop loss               |
   * | BO              | Bracket Order; entry, stop loss & target price |
   * | MTF             | Margin Traded Fund                             |
   *
   * **CO & BO product types will be valid only for Intraday**
   */
  productType?: 'CNC' | 'INTRADAY' | 'MARGIN' | 'MTF' | 'CO' | 'BO';

  /**
   * RBI mandated reference rate for forex
   */
  rbiReferenceRate?: number;

  /**
   * Profit or loss booked
   */
  realizedProfit?: number;

  /**
   * Exchange standard identification for each scrip
   */
  securityId?: string;

  /**
   * Average sell price
   */
  sellAvg?: number;

  /**
   * Total quantities sold
   */
  sellQty?: number;

  /**
   * Exchange standard trading symbol
   */
  tradingSymbol?: string;

  /**
   * Profit or loss standing for open position
   */
  unrealizedProfit?: number;
}

export type PositionListResponse = Array<Position>;

export interface PositionListParams {
  'access-token': string;
}

export interface PositionConvertParams {
  /**
   * Header param:
   */
  'access-token': string;

  /**
   * Body param: Number of shares for the conversion
   */
  convertQty?: number;

  /**
   * Body param: User specific identification generated by Dhan
   */
  dhanClientId?: string;

  /**
   * | Body param:  | **Enums** | **Exchange**      | **Segment** |
   * | ------------ | --------- | ----------------- | ----------- |
   * | NSE_EQ       | NSE       | Equity Cash       |
   * | NSE_FNO      | NSE       | Futures & Options |
   * | NSE_CURRENCY | NSE       | Currency          |
   * | BSE_EQ       | BSE       | Equity Cash       |
   * | BSE_FNO      | BSE       | Futures & Options |
   * | BSE_CURRENCY | BSE       | Currency          |
   * | MCX_COMM     | MCX       | Commodity         |
   */
  exchangeSegment?:
    | 'NSE_EQ'
    | 'NSE_FNO'
    | 'NSE_CURRENCY'
    | 'BSE_EQ'
    | 'BSE_FNO'
    | 'BSE_CURRENCY'
    | 'MCX_COMM';

  /**
   * | Body param: | **Enum Values**                        | **Description** |
   * | ----------- | -------------------------------------- | --------------- |
   * | CNC         | Cash & Carry for equity deliveries     |
   * | INTRADAY    | Intraday for Equity, Futures & Options |
   * | MARGIN      | Carry Forward in Futures & Options     |
   */
  fromProductType?: 'CNC' | 'INTRADAY' | 'MARGIN' | 'MTF' | 'CO' | 'BO';

  /**
   * | Body param: | **Enum Values**                                     | **Description** |
   * | ----------- | --------------------------------------------------- | --------------- |
   * | LONG        | When net bought quantity is more than sold quantity |
   * | SHORT       | When net sold quantity is more than bought quantity |
   * | CLOSED      | When no open position standing                      |
   */
  positionType?: 'LONG' | 'SHORT' | 'CLOSED';

  /**
   * Body param: Exchange standard identification for each scrip
   */
  securityId?: string;

  /**
   * | Body param: | **Enum Values**                        | **Description** |
   * | ----------- | -------------------------------------- | --------------- |
   * | CNC         | Cash & Carry for equity deliveries     |
   * | INTRADAY    | Intraday for Equity, Futures & Options |
   * | MARGIN      | Carry Forward in Futures & Options     |
   */
  toProductType?: 'CNC' | 'INTRADAY' | 'MARGIN' | 'MTF' | 'CO' | 'BO';
}

export namespace Positions {
  export import Position = PositionsAPI.Position;
  export import PositionListResponse = PositionsAPI.PositionListResponse;
  export import PositionListParams = PositionsAPI.PositionListParams;
  export import PositionConvertParams = PositionsAPI.PositionConvertParams;
}
