// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

export interface Order {
  /**
   * Flag to inform that the order placed is After Market Order
   */
  afterMarketOrder?: boolean;

  /**
   * Algo_ID
   */
  algoId?: string;

  /**
   * Average price at which order is traded
   */
  averageTradedPrice?: number;

  /**
   * Bracket order Target price
   */
  boProfitValue?: number;

  /**
   * Bracket Order/Cover Order Stop Loss Price
   */
  boStopLossValue?: number;

  /**
   * The user/partner generated id for tracking back
   */
  correlationId?: string;

  /**
   * Time at which the record is created
   */
  createTime?: string;

  /**
   * User specific identification generated by Dhan
   */
  dhanClientId?: string;

  /**
   * Number shares visible in the market depth
   */
  disclosedQuantity?: number;

  /**
   * For F&O, expiry date of contract
   */
  drvExpiryDate?: string;

  /**
   * For Options, type CALL or PUT
   */
  drvOptionType?: 'CALL' | 'PUT' | 'NA';

  /**
   * For Options, Strike Price
   */
  drvStrikePrice?: number;

  /**
   * Order specific identification generated by Exchange
   */
  exchangeOrderId?: string;

  /**
   * | **Enums**    | **Exchange** | **Segment**       |
   * | ------------ | ------------ | ----------------- |
   * | NSE_EQ       | NSE          | Equity Cash       |
   * | NSE_FNO      | NSE          | Futures & Options |
   * | NSE_CURRENCY | NSE          | Currency          |
   * | BSE_EQ       | BSE          | Equity Cash       |
   * | BSE_FNO      | BSE          | Futures & Options |
   * | BSE_CURRENCY | BSE          | Currency          |
   * | MCX_COMM     | MCX          | Commodity         |
   */
  exchangeSegment?:
    | 'NSE_EQ'
    | 'NSE_FNO'
    | 'NSE_CURRENCY'
    | 'BSE_EQ'
    | 'BSE_FNO'
    | 'BSE_CURRENCY'
    | 'MCX_COMM';

  /**
   * Time at which order reached at exchange end
   */
  exchangeTime?: string;

  /**
   * Filled Quantity
   */
  filledQty?: number;

  legName?: 'ENTRY_LEG' | 'STOP_LOSS_LEG' | 'TARGET_LEG' | 'NA';

  /**
   * When order is rejected or failed, omsErrorCode would be populated
   */
  omsErrorCode?: string;

  /**
   * When order is rejected or failed, omsErrorDescription would be populated
   */
  omsErrorDescription?: string;

  /**
   * Order specific identification generated by Dhan
   */
  orderId?: string;

  /**
   * | **Enum Values** | **Description**                             |
   * | --------------- | ------------------------------------------- |
   * | TRANSIT         | Did not reach the exchange server           |
   * | PENDING         | Reached at exchange end, awaiting execution |
   * | REJECTED        | Rejected at exchange/broker’s end           |
   * | CANCELLED       | Cancelled by user                           |
   * | PART_TRADED     | Partially Executed                          |
   * | TRADED          | Executed                                    |
   * | EXPIRED         | Validity of order is expired                |
   */
  orderStatus?: 'TRANSIT' | 'PENDING' | 'REJECTED' | 'CANCELLED' | 'PART_TRADED' | 'TRADED' | 'EXPIRED';

  /**
   * | **Enum Values**  | **Description**             |
   * | ---------------- | --------------------------- |
   * | LIMIT            | For Limit Order types       |
   * | MARKET           | For market Order types      |
   * | STOP_LOSS        | For Stop Loss Limit orders  |
   * | STOP_LOSS_MARKET | For Stop Loss Market orders |
   */
  orderType?: 'LIMIT' | 'MARKET' | 'STOP_LOSS' | 'STOP_LOSS_MARKET';

  /**
   * Price at which the order is requested to execute
   */
  price?: number;

  /**
   * | **Enum Values** | **Description**                                |
   * | --------------- | ---------------------------------------------- |
   * | CNC             | Cash & Carry for equity deliveries             |
   * | INTRADAY        | Intraday for Equity, Futures & Options         |
   * | MARGIN          | Carry Forward in Futures & Options             |
   * | CO              | Cover Order; entry and stop loss               |
   * | BO              | Bracket Order; entry, stop loss & target price |
   * | MTF             | Margin Traded Fund                             |
   *
   * **CO & BO product types will be valid only for Intraday**
   */
  productType?: 'CNC' | 'INTRADAY' | 'MARGIN' | 'MTF' | 'CO' | 'BO';

  /**
   * Number of shares for the order
   */
  quantity?: number;

  /**
   * Number of shares yet to be traded for the order
   */
  remainingQuantity?: number;

  /**
   * Exchange standard identification for each scrip
   */
  securityId?: string;

  /**
   * Exchange standard trading symbol
   */
  tradingSymbol?: string;

  /**
   * Signifies the type of transaction wether it's BUY or SELL
   */
  transactionType?: 'BUY' | 'SELL';

  /**
   * Price at which the order is triggered
   */
  triggerPrice?: number;

  /**
   * Time at which the record is updated
   */
  updateTime?: string;

  /**
   * | **Enum Values** | **Description**       |
   * | --------------- | --------------------- |
   * | DAY             | Valid till end of day |
   * | IOC             | Immediate or Cancel   |
   */
  validity?: 'DAY' | 'IOC';
}
